#!/bin/bash
# vim: set tabstop=8 shiftwidth=4 softtabstop=4 expandtab smarttab colorcolumn=80:
#
# Copyright (c) 2016 Red Hat, Inc.
# Author: Nathaniel McCallum <npmccallum@redhat.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

depends() {
    echo crypt systemd
    return 255
}

configure_passwd_watchers() {
    if ! command -v systemctl >/dev/null; then
        return 1
    fi

    find /etc/systemd/system/ -name "clevis-luks-askpass*" -exec rm -f {} \;

    local uuid
    for dev in $(lsblk -p -n -s -r \
                 | awk '$6 == "crypt" { getline; print $1 }' | sort -u); do
        uuid=$(cryptsetup luksUUID "${dev}")

        if clevis luks list -d "${dev}" >/dev/null 2>/dev/null; then
            systemctl enable "clevis-luks-askpass@${uuid}.path" 2>/dev/null
        fi
    done
}

install() {
    inst_hook initqueue/online 60 "$moddir/clevis-hook.sh"
    inst_hook initqueue/settled 60 "$moddir/clevis-hook.sh"

    inst_multiple \
	/etc/services \
        /usr/libexec/clevis-luks-askpass \
        clevis-luks-common-functions \
        head \
        grep \
        sed \
        clevis-decrypt \
        cryptsetup \
        luksmeta \
        clevis \
        mktemp \
        jose \
        ncat

    configure_passwd_watchers
    dracut_need_initqueue
}
